@@ -24,7 +24,7 @@ project = "Translate Toolkit"
 copyright = "2002-2022, Translate"
 
 # The short X.Y version.
-version = "3.6.0"
+version = "3.7.3"
 
 # The full version, including alpha/beta/rc tags
 release = version
@@ -212,9 +212,9 @@ intersphinx_mapping = {
 
 extlinks = {
     # :role: (URL, prefix)
-    "issue": ("https://github.com/translate/translate/issues/%s", "issue "),
-    "man": ("https://linux.die.net/man/1/%s", ""),
-    "wp": ("https://en.wikipedia.org/wiki/%s", ""),
+    "issue": ("https://github.com/translate/translate/issues/%s", "issue %s"),
+    "man": ("https://linux.die.net/man/1/%s", "%s"),
+    "wp": ("https://en.wikipedia.org/wiki/%s", "%s"),
 }
 
 # -- Options for Linkcheck -------------------------------------------------
